# FILE: accountGui.tcl
#

Oc_Class Net_AccountGui {
    const public variable winpath
    const public variable outer_frame_options = "-bd 4 -relief ridge"
    const public variable account
    private variable accountlabel
    private variable programs
    private variable threads
    private variable plabel
    private variable tlabel
    private variable threadbuttons = {}
    private variable myProgramButtons = {}
    Constructor {basewinpath args} {
	# Don't add '.' suffix if there already is one.
	# (This happens chiefly when basewinpath is exactly '.')
	if {![string match {.} \
		[string index $basewinpath \
		[expr [string length $basewinpath]-1]]]} {
	    append basewinpath {.}
	}
	eval $this Configure -winpath ${basewinpath}w$this $args

	# Pack entire subwidget into a subframe.  This makes
	# housekeeping easier, since the only bindings on
	# $winpath will be ones added from inside the class,
	# and also all subwindows can be destroyed by simply
	# destroying $winpath.  (The instance destructor should
	# not "destroy" $frame, because $frame is owned external
	# to this class.
	eval frame $winpath $outer_frame_options
        set accountname [$account Cget -accountname]
        set accountlabel [label $winpath.label -text $accountname \
                -relief groove]
        pack $accountlabel -side top -fill x
        set programs [frame $winpath.programs -relief groove]
        set threads [frame $winpath.threads -relief groove]
        set plabel [label $programs.label -text Programs -relief flat]
        set tlabel [label $threads.label -text Threads -relief flat]
        pack $plabel -side top -in $programs -fill x
        pack $tlabel -side top -in $threads -fill x
        pack $programs -side left -fill both  -expand 1
        pack $threads -side left -fill both -expand 1
        $this DisplayThreadButtons
        Oc_EventHandler New _ Net_Thread Delete [list $this \
                DisplayThreadButtons] -groups [list $this]
        Oc_EventHandler New _ Net_Thread Ready [list $this \
                DisplayThreadButtons] -groups [list $this]
        set qid [$account Send programs]
        Oc_EventHandler New _ $account Reply$qid [list $this \
                ProgramsReply $qid] -oneshot 1 -groups [list $this $this-$qid]
        Oc_EventHandler New _ $account Timeout$qid [list $this \
                ProgramsTimeout $qid] -oneshot 1 -groups [list $this $this-$qid]
	# Widget bindings
	bind $winpath <Destroy> "+$this WinDestroy %W"
    }
    method DisplayThreadButtons {} {
        foreach w $threadbuttons {
            destroy $w
        }
        set threadbuttons {}
        foreach thread [Net_Thread Instances] {
            if {[string match [$account Cget -accountname] \
                    [$thread Cget -accountname]] && [string match \
                    [$account Cget -hostname] [$thread Cget -hostname]]} {
                if {[$thread Ready]} {
                    if {[$thread HasGui]} {
                        set btn [checkbutton $threads.w$thread \
                              -text [$thread Cget -alias]<[$thread Cget -pid]> \
                              -variable [$thread GlobalName btnvar] \
                              -command [list $thread ToggleGui]]
                    } else {
                        set btn [label $threads.w$thread \
                              -text [$thread Cget -alias]<[$thread Cget -pid]>]
                    }
                    lappend threadbuttons $btn
                    pack $btn -side top -in $threads -fill x
                }
            }
        }
    }
    method ProgramsReply {id} {
        Oc_EventHandler DeleteGroup $this-$id
        set result [$account Get]
        if {![lindex $result 0]} {
            foreach pgm [lrange $result 1 end] {
                set btn [button $programs.$pgm -text $pgm]
                $btn configure -command [list $this LaunchProgram $pgm $btn]
                lappend myProgramButtons $btn
                pack $btn -side top -fill x 
            }
        } else {
            set msg "Error report from account service directory\
                    [$account Cget -hostname]:[$account Cget -accountname]:\
                    \n\t[lrange $result 1 end]\n\nIn reply to\
                    query:\n\tprograms"
            error $msg $msg
        }
    }
    method LaunchProgram { pgm btn } {
        $btn configure -state disabled
        set qid [$account Send launch $pgm]
        Oc_EventHandler New _ $account Reply$qid [list $this \
                LaunchReply $btn $qid $pgm] -oneshot 1 \
                -groups [list $this $this-$qid]
        Oc_EventHandler New _ $account Timeout$qid [list $this \
                LaunchTimeout $btn $qid] -oneshot 1 \
                -groups [list $this $this-$qid]
    }
    method LaunchReply { btn id pgm } {
        Oc_EventHandler DeleteGroup $this-$id
        if {[winfo exists $btn]} {
            $btn configure -state normal
        }
        set result [$account Get]
        if {[lindex $result 0]} {
            set msg "Error report from account service directory\
                    [$account Cget -hostname]:[$account Cget -accountname]:\
                    \n\t[lrange $result 1 end]\n\nIn reply to\
                    query:\n\tlaunch $pgm"
            error $msg $msg
        }
    }
    method LaunchTimeout { btn id } {
        Oc_EventHandler DeleteGroup $this-$id
        if {[winfo exists $btn]} {
            $btn configure -state normal
        }
        set msg "Timeout waiting for account service directory\
                [$account Cget -hostname]:[$account Cget -accountname]\
                \nto reply to query:\n\tlaunch $pgm"
        error $msg $msg
    }
    method ProgramsTimeout {id} {
        Oc_EventHandler DeleteGroup $this-$id
        set msg "Timeout waiting for account service directory\
                [$account Cget -hostname]:[$account Cget -accountname]\
                \nto reply to query:\n\tprograms"
        error $msg $msg
    }
    method WinDestroy { w } { winpath } {
	if {[string compare $winpath $w]!=0} { return } ;# Child destroy event
	$this Delete
    }
    private variable delete_in_progress = 0
    Destructor {
	# Protect against re-entrancy
	if { [info exists delete_in_progress] && \
		$delete_in_progress } { return }
	set delete_in_progress 1
        Oc_EventHandler DeleteGroup $this
	# Delete everything else
	if {[info exists winpath] && [winfo exists $winpath]} {
	    # Destroy instance frame, all children, and bindings
	    destroy $winpath
	}
    }
}
